@@ -1,6 +1,7 @@
 from contextlib import contextmanager
 import inspect
 from io import BytesIO
+from io import StringIO
 from io import TextIOWrapper
 import os
 import re
@@ -11,12 +12,10 @@ from sqlalchemy import text
 from alembic import __version__
 from alembic import command
 from alembic import config
-from alembic import testing
 from alembic import util
 from alembic.script import ScriptDirectory
 from alembic.testing import assert_raises
 from alembic.testing import assert_raises_message
-from alembic.testing import config as testing_config
 from alembic.testing import eq_
 from alembic.testing import is_false
 from alembic.testing import is_true
@@ -34,11 +33,10 @@ from alembic.testing.env import write_script
 from alembic.testing.fixtures import capture_context_buffer
 from alembic.testing.fixtures import capture_engine_context_buffer
 from alembic.testing.fixtures import TestBase
-from alembic.util import compat
 from alembic.util.sqla_compat import _connectable_has_table
 
 
-class _BufMixin(object):
+class _BufMixin:
     def _buf_fixture(self):
         # try to simulate how sys.stdout looks - we send it u''
         # but then it's trying to encode to something.
@@ -538,7 +536,7 @@ finally:
         command.revision(self.cfg, sql=True)
 
 
-class _StampTest(object):
+class _StampTest:
     def _assert_sql(self, emitted_sql, origin, destinations):
         ins_expr = (
             r"INSERT INTO alembic_version \(version_num\) "
@@ -924,7 +922,7 @@ class EditTest(TestBase):
             % (EditTest.cfg.config_args["here"], EditTest.c)
         )
 
-        with mock.patch("alembic.util.edit") as edit:
+        with mock.patch("alembic.util.open_in_editor") as edit:
             command.edit(self.cfg, "head")
             edit.assert_called_with(expected_call_arg)
 
@@ -934,22 +932,10 @@ class EditTest(TestBase):
             % (EditTest.cfg.config_args["here"], EditTest.b)
         )
 
-        with mock.patch("alembic.util.edit") as edit:
+        with mock.patch("alembic.util.open_in_editor") as edit:
             command.edit(self.cfg, self.b[0:3])
             edit.assert_called_with(expected_call_arg)
 
-    @testing_config.requirements.editor_installed
-    @testing.emits_python_deprecation_warning("the imp module is deprecated")
-    def test_edit_with_missing_editor(self):
-        with mock.patch("editor.edit") as edit_mock:
-            edit_mock.side_effect = OSError("file not found")
-            assert_raises_message(
-                util.CommandError,
-                "file not found",
-                util.edit,
-                "/not/a/file.txt",
-            )
-
     def test_edit_no_revs(self):
         assert_raises_message(
             util.CommandError,
@@ -975,7 +961,7 @@ class EditTest(TestBase):
         )
 
         command.stamp(self.cfg, self.b)
-        with mock.patch("alembic.util.edit") as edit:
+        with mock.patch("alembic.util.open_in_editor") as edit:
             command.edit(self.cfg, "current")
             edit.assert_called_with(expected_call_arg)
 
@@ -1187,8 +1173,8 @@ class CommandLineTest(TestBase):
             )
 
     def test_version_text(self):
-        buf = compat.StringIO()
-        to_mock = "sys.stdout" if util.compat.py3k else "sys.stderr"
+        buf = StringIO()
+        to_mock = "sys.stdout"
 
         with mock.patch(to_mock, buf):
             try:
